<?php
/**
 * Plugin Name: Weengle Simple Contact Form Logger
 * Plugin URI: https://www.weengle.com/simple-contact-form-logger-v2/
 * Description: Adds a contact form with logging, email alerts, spam protection, and CSV export.
 * Version: 2.0
 * Author: Debasis Pradhan
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if (!defined('ABSPATH')) exit;

class WeengleContactFormLoggerV2 {

    public function __construct() {
        add_shortcode('weengle_contact_form', [$this, 'render_contact_form']);
        add_action('init', [$this, 'handle_form_submission']);
        add_action('admin_menu', [$this, 'create_admin_menu']);
        add_action('admin_post_scfl_export_csv', [$this, 'export_submissions_csv']);
        register_activation_hook(__FILE__, [$this, 'create_database_table']);
    }

    public function render_contact_form() {
        ob_start();
        ?>
        <form method="post" action="">
            <input type="hidden" name="scfl_token" value="<?php echo wp_create_nonce('scfl_nonce'); ?>">
            <p><input type="text" name="scfl_name" placeholder="Your Name" required></p>
            <p><input type="email" name="scfl_email" placeholder="Your Email" required></p>
            <p><textarea name="scfl_message" placeholder="Your Message" required></textarea></p>
            <p style="display:none;"><input type="text" name="scfl_honeypot"></p> <!-- Honeypot -->
            <p><input type="submit" name="scfl_submit" value="Send"></p>
        </form>
        <?php if (isset($_GET['scfl_status']) && $_GET['scfl_status'] === 'success') {
            echo '<p style="color:green;">Message Sent Successfully!</p>';
        } ?>
        <?php
        return ob_get_clean();
    }

    public function handle_form_submission() {
        if (isset($_POST['scfl_submit']) && wp_verify_nonce($_POST['scfl_token'], 'scfl_nonce')) {
            if (!empty($_POST['scfl_honeypot'])) {
                return; // Spam bot detected
            }

            global $wpdb;
            $table_name = $wpdb->prefix . 'scfl_submissions';

            $name = sanitize_text_field($_POST['scfl_name']);
            $email = sanitize_email($_POST['scfl_email']);
            $message = sanitize_textarea_field($_POST['scfl_message']);

            $wpdb->insert($table_name, [
                'name' => $name,
                'email' => $email,
                'message' => $message,
                'submitted_at' => current_time('mysql')
            ]);

            // Send Email Notification
            $admin_email = get_option('admin_email');
            wp_mail($admin_email, 'New Contact Form Submission', "Name: $name\nEmail: $email\nMessage:\n$message");

            // Redirect with confirmation
            wp_redirect(add_query_arg('scfl_status', 'success', wp_get_referer()));
            exit;
        }
    }

    public function create_database_table() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'scfl_submissions';

        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            name tinytext NOT NULL,
            email varchar(100) NOT NULL,
            message text NOT NULL,
            submitted_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            PRIMARY KEY  (id)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    public function create_admin_menu() {
        add_menu_page(
            'Contact Form Logs',
            'Contact Form Logs',
            'manage_options',
            'scfl-submissions',
            [$this, 'display_submissions']
        );
    }

    public function display_submissions() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'scfl_submissions';
        $results = $wpdb->get_results("SELECT * FROM $table_name ORDER BY submitted_at DESC");

        echo '<div class="wrap"><h1>Contact Form Submissions</h1>';
        echo '<a href="' . admin_url('admin-post.php?action=scfl_export_csv') . '" class="button button-primary">Export CSV</a><br><br>';
        echo '<table class="widefat fixed"><thead><tr><th>Name</th><th>Email</th><th>Message</th><th>Date</th></tr></thead><tbody>';

        foreach ($results as $row) {
            echo '<tr>';
            echo '<td>' . esc_html($row->name) . '</td>';
            echo '<td>' . esc_html($row->email) . '</td>';
            echo '<td>' . esc_html($row->message) . '</td>';
            echo '<td>' . esc_html($row->submitted_at) . '</td>';
            echo '</tr>';
        }

        echo '</tbody></table></div>';
    }

    public function export_submissions_csv() {
        if (!current_user_can('manage_options')) wp_die('Unauthorized');

        global $wpdb;
        $table_name = $wpdb->prefix . 'scfl_submissions';
        $results = $wpdb->get_results("SELECT * FROM $table_name", ARRAY_A);

        header('Content-Type: text/csv');
        header('Content-Disposition: attachment; filename="contact-submissions.csv"');
        $output = fopen('php://output', 'w');

        fputcsv($output, ['ID', 'Name', 'Email', 'Message', 'Date']);
        foreach ($results as $row) {
            fputcsv($output, $row);
        }
        fclose($output);
        exit;
    }
}

new WeengleContactFormLoggerV2();